@@ -6,6 +6,8 @@ import os
 import sys
 from colorama import init as colorama_init, Fore
 import click
+import traceback
+from getpass import getpass
 
 from flask import current_app as app
 from flask.cli import FlaskGroup, pass_script_info
@@ -13,11 +15,12 @@ from flask.cli import FlaskGroup, pass_script_info
 from covfee.server.start import create_app
 from ...covfee_folder import CovfeeFolder, ProjectExistsException
 from halo.halo import Halo
-from covfee.shared.validator.validation_errors import ValidationError
+from covfee.shared.validator.validation_errors import JavascriptError, ValidationError
 from covfee.shared.schemata import Schemata
 from covfee.cli.utils import NPMPackage
 from covfee import _make as covfee_make, start_deepstream
 from covfee.server.rtstore import rtstore
+from covfee.server.orm import set_frontend_config
 
 colorama_init()
 
@@ -40,8 +43,10 @@ def start_covfee(socketio, app, mode='local', host='localhost'):
         # run the realtime store service
         rtstore.run()
 
+    set_frontend_config()
+
     if mode == 'local':
-        socketio.run(app, host=host, port=5000 **ssl_options)
+        socketio.run(app, host=host, port=5000, **ssl_options)
     elif mode == 'dev':
         socketio.run(app, host=host, port=5000, debug=True, **ssl_options)
     elif mode == 'deploy':
@@ -93,7 +98,8 @@ def launch_deepstream():
 @click.option("--dev", is_flag=True, help="Run covfee in dev mode")
 @click.option("--deploy", is_flag=True, help="Run covfee in deployment mode")
 @click.option('--no-browser', is_flag=True, help='Disables launching of the web browser.')
-def start(dev, deploy, no_browser):
+@click.option('--safe', is_flag=True, help='Enables login protection in local and dev mode (disabled by default).')
+def start(dev, deploy, no_browser, safe):
     """
     Starts covfee in local mode by default. Use --deploy or --dev to start deployment (public) or development servers.
     """
@@ -101,7 +107,7 @@ def start(dev, deploy, no_browser):
     mode = 'local'
     if dev: mode = 'dev'
     if deploy: mode = 'deploy'
-    unsafe_mode_on = (mode in ['local', 'dev'])
+    unsafe = False if mode == 'deploy' else (not safe)
 
     socketio, app = create_app(mode)  
 
@@ -112,10 +118,9 @@ def start(dev, deploy, no_browser):
                                 ' covfee maker in the current folder?')
 
         if not no_browser:
-            covfee_folder.launch_in_browser(unsafe_mode_on)
+            covfee_folder.launch_in_browser(unsafe)
 
-        # covfee_folder.launch_prod(unsafe, launch_browser=not no_browser)
-        app.config['UNSAFE_MODE_ON'] = unsafe_mode_on
+        app.config['UNSAFE_MODE_ON'] = unsafe
         start_covfee(socketio, app, mode)
 
 
@@ -152,13 +157,17 @@ def installjs():
 
 @covfee_cli.command()
 @click.option("--force", is_flag=True, help="Specify to overwrite existing databases.")
-@click.option("--unsafe", is_flag=True, help="Disables authentication for the covfee instance.")
+@click.option("--deploy", is_flag=True, help="Run covfee in deployment / production mode.")
+@click.option("--safe", is_flag=True, help="Enable authentication in local mode.")
 @click.option("--rms", is_flag=True, help="Re-makes the schemata for validation.")
 @click.option("--no-launch", is_flag=True, help="Do not launch covfee, only make the DB")
 @click.option("--no-browser", is_flag=True, help="Do not launch in the browser")
 @click.argument("file_or_folder")
-def make(force, unsafe, rms, no_browser, no_launch, file_or_folder):
-    socketio, app = create_app('local')
+def make(force, deploy, safe, rms, no_browser, no_launch, file_or_folder):
+
+    mode = 'deploy' if deploy else 'local'
+    unsafe = False if deploy else (not safe)
+    socketio, app = create_app(mode)
 
     with app.app_context():
         install_npm_packages_if_not_installed()
@@ -167,12 +176,17 @@ def make(force, unsafe, rms, no_browser, no_launch, file_or_folder):
             covfee_make(file_or_folder, force=force, rms=rms, stdout_enabled=True)
         except FileNotFoundError:
             pass
+        except JavascriptError as err:
+            return print('This is likely an issue with the Covfee app. Please contact the developers or post an issue with the following error message. \n' + err.js_stack_trace)
         except ValidationError as err:
             return err.print_friendly()
         except ProjectExistsException as err:
-            return print(' Add --force option to overwrite.')
+            return print('Project exists in covfee. Add --force option to overwrite.')
         except Exception as err:
-            return print(err)
+            print(traceback.format_exc())
+            if 'js_stack_trace' in dir(err):
+                print(err.js_stack_trace)
+            return
 
         if no_launch: 
             return
@@ -197,5 +211,5 @@ def mkuser():
             project_folder.init()
 
         username = input('Please enter username: ')
-        password = input('Please enter password: ')
+        password = getpass()
         project_folder.mkuser(username, password)
